@@ -1,6 +1,10 @@
-import nltk.data
 import os
-from pycaption import BaseWriter
+
+try:
+    import nltk.data
+except ImportError:
+    raise ImportError('You must install nltk==2.0.4 and numpy==1.7.1 to be able to use this.')
+from pycaption import BaseWriter, CaptionNode
 
 
 class TranscriptWriter(BaseWriter):
@@ -11,11 +15,11 @@ class TranscriptWriter(BaseWriter):
     def write(self, captions):
         transcripts = []
 
-        for lang in captions['captions']:
+        for lang in captions.get_languages():
             lang_transcript = '* %s Transcript *\n' % lang.upper()
 
-            for sub in captions['captions'][lang]:
-                lang_transcript = self._strip_text(sub[2], lang_transcript)
+            for caption in captions.get_captions(lang):
+                lang_transcript = self._strip_text(caption.nodes, lang_transcript)
 
             lang_transcript = '\n'.join(self.nltk.tokenize(lang_transcript))
             transcripts.append(lang_transcript)
@@ -23,7 +27,7 @@ class TranscriptWriter(BaseWriter):
         return '\n'.join(transcripts)
 
     def _strip_text(self, elements, lang_transcript):
-        for line in elements:
-            if line['type'] == 'text':
-                lang_transcript += '%s ' % line['content']
+        for el in elements:
+            if el.type == CaptionNode.TEXT:
+                lang_transcript += el.content
         return lang_transcript
