@@ -37,6 +37,7 @@ class WebVTTReader(BaseReader):
 
     def _parse(self, lines):
         captions = []
+        caption = None
 
         found_timing = False
 
@@ -48,13 +49,14 @@ class WebVTTReader(BaseReader):
                 try:
                     caption = self._parse_timing_line(line, last_start_time)
                 except CaptionReadError as e:
-                    raise type(e), str(e) + ' (line %d)', sys.exc_info()[2]
+                    new_message = '%s (line %d)' % (e.args[0], timing_line)
+                    raise type(e), new_message, sys.exc_info()[2]
 
             elif '' == line:
                 if found_timing:
                     if caption.is_empty():
                         raise CaptionReadSyntaxError(
-                                'Cue without content. (line %d)' % timing_line)
+                            'Cue without content. (line %d)' % timing_line)
                     else:
                         found_timing = False
                         captions.append(caption)
@@ -69,6 +71,9 @@ class WebVTTReader(BaseReader):
                     # it's a comment or some metadata; ignore it
                     pass
 
+        if caption and not caption.is_empty():
+            captions.append(caption)
+
         return captions
 
     def _remove_styles(self, line):
@@ -79,17 +84,17 @@ class WebVTTReader(BaseReader):
         m = TIMING_PATTERN.search(line)
         if not m:
             raise CaptionReadSyntaxError(
-                    'Invalid timing format.')
+                'Invalid timing format.')
 
         caption = Caption()
 
         caption.start = self._parse_timestamp(m.group(1))
-        if not caption.start:
+        if caption.start is None:
             raise CaptionReadSyntaxError(
-                    'Invalid cue start timestamp.')
+                'Invalid cue start timestamp.')
 
         caption.end = self._parse_timestamp(m.group(2))
-        if not caption.end:
+        if caption.end is None:
             raise CaptionReadSyntaxError('Invalid cue end timestamp.')
 
         if caption.start > caption.end:
@@ -97,8 +102,8 @@ class WebVTTReader(BaseReader):
 
         if caption.start < last_start_time:
             raise CaptionReadError(
-                    'Start timestamp is not greater than or equal'
-                    'to start timestamp of previous cue.')
+                'Start timestamp is not greater than or equal'
+                'to start timestamp of previous cue.')
 
         return caption
 
